==> jc-1.4.0.tar.gz: javax/crypto/spec/IvParameterSpec.h <==
// public class javax.crypto.spec.IvParameterSpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e389cb8e6ce306d7 javax_crypto_spec_IvParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_IvParameterSpec_H_
#define _JC_javax_crypto_spec_IvParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_IvParameterSpec$sub_refs	_jc_javax_crypto_spec_IvParameterSpec$sub_refs;
typedef struct _jc_javax_crypto_spec_IvParameterSpec$sub_nonrefs	_jc_javax_crypto_spec_IvParameterSpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_IvParameterSpec$refs	_jc_javax_crypto_spec_IvParameterSpec$refs;
typedef struct _jc_javax_crypto_spec_IvParameterSpec$nonrefs	_jc_javax_crypto_spec_IvParameterSpec$nonrefs;
typedef struct _jc_javax_crypto_spec_IvParameterSpec$object	_jc_javax_crypto_spec_IvParameterSpec$object;

typedef const struct _jc_javax_crypto_spec_IvParameterSpec$vmethods	_jc_javax_crypto_spec_IvParameterSpec$vmethods;
typedef const struct _jc_javax_crypto_spec_IvParameterSpec$vtable	_jc_javax_crypto_spec_IvParameterSpec$vtable;
typedef const struct _jc_javax_crypto_spec_IvParameterSpec$vtype	_jc_javax_crypto_spec_IvParameterSpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_IvParameterSpec$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_javax_crypto_spec_IvParameterSpec$object *, struct _jc_byte_array *);
extern void _jc_javax_crypto_spec_IvParameterSpec$method$_init$4ff4a7925ef7b06c(_jc_env *, struct _jc_javax_crypto_spec_IvParameterSpec$object *, struct _jc_byte_array *, jint, jint);

// Virtual methods
extern _jc_byte_array *_jc_javax_crypto_spec_IvParameterSpec$method$getIV$4134a0c13b73072e(_jc_env *, struct _jc_javax_crypto_spec_IvParameterSpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_IvParameterSpec$method_info$getIV$4134a0c13b73072e;

// Virtual methods structure
struct _jc_javax_crypto_spec_IvParameterSpec$vmethods {
	_jc_byte_array	*(*getIV$4134a0c13b73072e)(_jc_env *, struct _jc_javax_crypto_spec_IvParameterSpec$object *);
};

// Vtable
struct _jc_javax_crypto_spec_IvParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_IvParameterSpec$vmethods	javax_crypto_spec_IvParameterSpec;
};

// Vtype
struct _jc_javax_crypto_spec_IvParameterSpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_IvParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_IvParameterSpec$sub_refs {
	_jc_byte_array	*iv;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_IvParameterSpec$refs {
    _jc_javax_crypto_spec_IvParameterSpec$sub_refs	javax_crypto_spec_IvParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_IvParameterSpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_IvParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_IvParameterSpec$sub_nonrefs	javax_crypto_spec_IvParameterSpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_IvParameterSpec$object {
	_jc_javax_crypto_spec_IvParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_IvParameterSpec$vtype	*vtype;
	_jc_javax_crypto_spec_IvParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_IvParameterSpec$vtype _jc_javax_crypto_spec_IvParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_IvParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_IvParameterSpec$class_object;

#endif	/* _JC_javax_crypto_spec_IvParameterSpec_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/spec/IvParameterSpec.h <==
// public class javax.crypto.spec.IvParameterSpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e389cb8e6ce306d7 javax_crypto_spec_IvParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_IvParameterSpec_H_
#define _JC_javax_crypto_spec_IvParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_IvParameterSpec$sub_refs	_jc_javax_crypto_spec_IvParameterSpec$sub_refs;
typedef struct _jc_javax_crypto_spec_IvParameterSpec$sub_nonrefs	_jc_javax_crypto_spec_IvParameterSpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_IvParameterSpec$refs	_jc_javax_crypto_spec_IvParameterSpec$refs;
typedef struct _jc_javax_crypto_spec_IvParameterSpec$nonrefs	_jc_javax_crypto_spec_IvParameterSpec$nonrefs;
typedef struct _jc_javax_crypto_spec_IvParameterSpec$object	_jc_javax_crypto_spec_IvParameterSpec$object;

typedef const struct _jc_javax_crypto_spec_IvParameterSpec$vmethods	_jc_javax_crypto_spec_IvParameterSpec$vmethods;
typedef const struct _jc_javax_crypto_spec_IvParameterSpec$vtable	_jc_javax_crypto_spec_IvParameterSpec$vtable;
typedef const struct _jc_javax_crypto_spec_IvParameterSpec$vtype	_jc_javax_crypto_spec_IvParameterSpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_IvParameterSpec$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_javax_crypto_spec_IvParameterSpec$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_spec_IvParameterSpec$method$_init$4ff4a7925ef7b06c(_jc_env *, struct _jc_javax_crypto_spec_IvParameterSpec$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_javax_crypto_spec_IvParameterSpec$method$getIV$4134a0c13b73072e(_jc_env *, struct _jc_javax_crypto_spec_IvParameterSpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_IvParameterSpec$method_info$getIV$4134a0c13b73072e;

// Virtual methods structure
struct _jc_javax_crypto_spec_IvParameterSpec$vmethods {
	_jc_byte_array	*(*getIV$4134a0c13b73072e)(_jc_env *, struct _jc_javax_crypto_spec_IvParameterSpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_spec_IvParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_IvParameterSpec$vmethods	javax_crypto_spec_IvParameterSpec;
};

// Vtype
struct _jc_javax_crypto_spec_IvParameterSpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_IvParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_IvParameterSpec$sub_refs {
	_jc_byte_array	*iv;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_IvParameterSpec$refs {
    _jc_javax_crypto_spec_IvParameterSpec$sub_refs	javax_crypto_spec_IvParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_IvParameterSpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_IvParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_IvParameterSpec$sub_nonrefs	javax_crypto_spec_IvParameterSpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_IvParameterSpec$object {
	_jc_javax_crypto_spec_IvParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_IvParameterSpec$vtype	*vtype;
	_jc_javax_crypto_spec_IvParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_IvParameterSpec$vtype _jc_javax_crypto_spec_IvParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_IvParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_IvParameterSpec$class_object;

#endif	/* _JC_javax_crypto_spec_IvParameterSpec_H_ */
